@@ -254,7 +254,8 @@ class ReduceBlocks:
                 if block.unconditional_init:
                     if is_debug:
                         first_phase_code.add_line(
-                            "globals()['__BROKEN_EARLY__'] = True", 0
+                            "globals()['__BROKEN_EARLY__'] = True  # DEBUG ONLY",
+                            0,
                         )
                     first_phase_code.add_line("break", 0)
                 else:
@@ -263,7 +264,8 @@ class ReduceBlocks:
                     )
                     if is_debug:
                         first_phase_code.add_line(
-                            "globals()['__BROKEN_EARLY__'] = True", 0
+                            "globals()['__BROKEN_EARLY__'] = True  # DEBUG ONLY",
+                            0,
                         )
                     first_phase_code.add_line("break", -1)
 
@@ -316,7 +318,7 @@ class ReduceBlocks:
             )
             if is_debug:
                 resulting_code.add_line(
-                    "globals()['__BROKEN_EARLY__'] = True", 0
+                    "globals()['__BROKEN_EARLY__'] = True  # DEBUG ONLY", 0
                 )
             resulting_code.add_line("break", -1)
         resulting_code.incr_indent_level(-1)
@@ -442,7 +444,11 @@ class MultiStatementReducer(BaseReducer):
 
     def __init__(self, *expressions, initial=_none, default=_none, where=None):
         super().__init__(default, initial)
-        self.where = _none if where is None else self.ensure_conversion(where)
+        self.where = (
+            _none
+            if (where is None or where is _none)
+            else self.ensure_conversion(where)
+        )
 
         self.expressions = tuple(
             self.ensure_conversion(expr)
@@ -577,7 +583,11 @@ class Reduce(BaseReducer):
             aggregation value OR there is a condition for that
         """
         super().__init__(default, initial)
-        self.where = _none if where is None else self.ensure_conversion(where)
+        self.where = (
+            _none
+            if (where is None or where is _none)
+            else self.ensure_conversion(where)
+        )
         self.to_call_with_2_args = self.ensure_conversion(to_call_with_2_args)
         self.expressions = tuple(
             self.ensure_conversion(expr) for expr in expressions
